pro ssw_pfss_synop, times0, time1, ndays=ndays, nlines=nlines, $
   thumbmag=thumbmag, thumbwidth=thumbwidth, $
   fullmag=fullmag, fullwidth=fullwidth, cadence_hours=cadence_hours, $
   outdir=outdir

;+
;
;   Name: ssw_pfss_synop
;
;   Purpose: generate PFSS image files for each synoptic (eit/sxi) image
;            
;   Input Parameters:
;       time0,time1 - optional time range
;      
;
;   Keyword Parameters:
;      ndays - number of days to consider (ie, look back queue size)
;      nlines - pass to ssw_index2pfss_cube (number lines per radii)
;      thumbmag/thumbwidth - MAG and WIDTH pfss params for thumbnails (les) 
;      fullmag/fullwidth   - ditto for full size equivilents 
;      cadence_hours=cadence_hours - if time range supplied (overrides 
;                                    default which is sxi l1q synop cadence
;                                    which in turn is EIT synoptic (01,07,13,20)
;  
;   Method:
;      default: sxi_l1q contents drives cadence
;-

if n_elements(ndays) eq 0 then ndays=5     ; look back window

if n_elements(cadence_hours) eq 0 then cadence_hours=6 

if n_elements(outdir) eq 0 then  $
   outdir=concat_dir('$SSWDB','packages/pfss/l1q_synop')

if n_elements(thumbwidth) eq 0 then thumbwidth=1.5 ; from les default
if n_elements(thumbmag) eq 0 then thumbmag=.5
if n_elements(fullwidth) eq 0 then fullwidth=2.
if n_elements(fullmag) eq 0 then fullmag=2.

case 1 of 
   n_params() eq 2: begin 
      wanttimes=timegrid(time0,time1,hours=cadence_hours,out='int')
   endcase
   else: begin
      sxisynd=concat_dir('$SSWDB','goes/sxig12/l1q_synop')
      sxisynop=findfile(sxisynd)
      wanttimes=file2time(last_nelem(sxisynop,ndays*4),out='int')
   endcase
endcase

curf=findfile(outdir)

; pfss_yyyymmdd_hhmmss_Bfield_yyyymmdd_hhmmss
ncnt=n_elements(wanttimes)
if curf(0) ne '' then begin 
   thumbss=where(strpos(curf,'thumb') ne -1, tcnt)
   if tcnt eq 0 then begin
      box_message,'No thumbs???? - returning'
      return
   endif
   curf=curf(thumbss)
   break_file,curf,ll,pp,ff,ee,vv
   ft0=ssw_strsplit(ff,'Bfield',tail=ft1)
   curtimes=file2time(curf,out='int')
   ss=tim2dset(wanttimes,curtimes,delta=dts)
   need=dts gt (cadence_hours * 3600.)
   chkss=where(1-need,chkcnt)
   for i=0, chkcnt-1 do begin
      curbf=pfss_time2file(file2time(ft0(chkss(i)),out='int'),/url)
      needit=ssw_deltat(file2time(curbf(0),out='int'), $
                        file2timeft1(chkss(i)),out='int' ) ne 0
      need(chkss(i))=needit
      if needit then begin  ; remove old one...
         box_message,'Newer PFSS file online - removing obsolete synop
         ssw_file_delete,curf(chkss(i))
      
      endif
   endfor
   needss=where(need,ncnt)
endif else needss=lindgen(n_elements(wanttimes))

case n_elements(nlines) of 
   0: nls=[50,100]
   1: nls=replicate(nlines,2)
   else: nls=nlines(0:1)
endcase

types=str2arr('thumb,full')
mags=[thumbmag,fullmag]
widths=[thumbwidth, fullwidth]  
pdefs=[0,252,250,254]
ldefs=[11,12,7,5]                         ; PFSS -> LINECOLORS mapping


tvlct,rs,gs,bs,/get                       ; preserve ct
dtemp=!d.name
set_plot,'z'
wdef,xx,/zbuffer
linecolors
tvlct,r,g,b,/get
for i=0,ncnt-1 do begin                   ; for each needed  
   for np=0,n_elements(mags)-1 do begin   ; for each mag/width combo
     newpfss=pfss_time2file(wanttimes(needss(i)),/url)
     fname='pfss_'+time2file(wanttimes(needss(i)))+$
           '_Bfield'+strextract(newpfss,'Bfield','.sav') + '_'+ types(np)+'.png'
     ssw_index2pfss_multi,wanttimes(needss(i)),pii,pdd,$
        mag=mags(np),  width=widths(np), nlines=nls(np), $
        /earth_view,start_radius=[1.0,2.5]
     for col=0,n_elements(pdefs)-1 do begin 
        ss=where(pdd eq pdefs(col),sscnt)
        if sscnt gt 0 then pdd(ss)=ldefs(col)
     endfor
     tv,pdd
     zbuff2file2,concat_dir(outdir,fname),r,g,b    ; update dbase
   endfor                       ; end of this MAG/WIDTH combo
endfor
set_plot,dtemp
tvlct,rs,gs,bs                  ;restore CT

return
end 
